package com.jcg;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Arrays;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.JTextField;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;
import javax.swing.UIManager.LookAndFeelInfo;
import javax.swing.border.TitledBorder;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

/**
 * @author ashraf_sarhan
 * 
 */
public class SwingJListDemo {

	public static void main(String[] args) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				try {
					setLookAndFeel(Constants.NIMBUS_LF);
					createAndShowGUI();
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	public static void createAndShowGUI() throws Exception {

		JFrame frame = new JFrame("Swing JList Demo");
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

		// Create JList with a List of String names
		SwingJList<String> swingJList = new SwingJList<>(
				Arrays.asList(Constants.LIST_DATA));

		JTextField nameField = new JTextField(26);

		// Adding a list selection listener
		swingJList.addListSelectionListener(new ListSelectionListener() {
			@Override
			public void valueChanged(ListSelectionEvent e) {
				if (!e.getValueIsAdjusting()) {
					String selectedName = swingJList.getSelectedValue();
					nameField.setText(selectedName);
				}
			}
		});

		// Create an action listener to add a new item to the List
		JButton addButton = new JButton("Add Employee");
		addButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				String name = nameField.getText();
				if (name != null && !"".equals(name)) {
					swingJList.addElement(name);
				} else {
					JOptionPane.showMessageDialog(null,
							"Employee name is empty", "Error",
							JOptionPane.ERROR_MESSAGE);
				}
			}
		});

		// Create an action listener to remove existed item from the List
		JButton deleteButton = new JButton("Delete Employee");
		deleteButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				String name = nameField.getText();
				if (name != null && !"".equals(name)) {
					swingJList.removeElement(name);
				} else {
					JOptionPane.showMessageDialog(null,
							"Please, select employee name from the list",
							"Warning", JOptionPane.WARNING_MESSAGE);
				}
			}
		});

		// Put the JList in a JScrollPane to handle scrolling
		JScrollPane listScrollPane = new JScrollPane(swingJList);
		listScrollPane.setPreferredSize(new Dimension(250, 200));

		listScrollPane.setBorder(BorderFactory.createTitledBorder(
				BorderFactory.createEtchedBorder(), "Employees List",
				TitledBorder.CENTER, TitledBorder.TOP));

		// Create a control panel
		JPanel buttonPane = new JPanel();
		buttonPane.add(nameField);
		buttonPane.add(addButton);
		buttonPane.add(deleteButton);

		JSplitPane splitPane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT,
				listScrollPane, buttonPane);
		splitPane.setDividerLocation(250);
		splitPane.setEnabled(false);

		frame.add(splitPane);
		frame.pack();
		frame.setLocationRelativeTo(null);
		frame.setVisible(true);
	}

	public static void setLookAndFeel(String lf) throws Exception {
		// Set Nimbus as L&F
		try {
			for (LookAndFeelInfo info : UIManager.getInstalledLookAndFeels()) {
				if (lf.equals(info.getName())) {
					UIManager.setLookAndFeel(info.getClassName());
					break;
				}
			}
		} catch (Exception e) {
			// If Nimbus is not available, you can set the GUI the system
			// default L&F.
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
		}
	}

}
